@@ -6,7 +6,7 @@ use warnings FATAL => 'all';
 use MRO::Compat;
 use Devel::InnerPackage qw/list_packages/;
 
-our $VERSION = '0.71_02';
+our $VERSION = '0.42';
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 our $this_package = __PACKAGE__; # so it can be used in hash keys
 
@@ -19,9 +19,7 @@ sub setup_components {
         Controller::Root
         Controller::Static
         Controller::AJAX
-        Controller::Skinny
-        Model::Metadata::DBIC
-        Model::Backend::DBIC
+        Model::Metadata
         View::JSON
         View::TT
     );
@@ -43,8 +41,7 @@ sub setup_components {
             );
 
             eval q{
-                package # hide from the PAUSE
-                    AutoCRUD::Loader::Schema;
+                package AutoCRUD::Loader::Schema;
                 use base 'DBIx::Class::Schema';
                 AutoCRUD::Loader::Schema->load_classes();
                 1;
@@ -57,11 +54,10 @@ sub setup_components {
 
     # bodge the config for chained PathPart so the user can use our basepath
     # shortcut in their config, which is less verbose than Cat's alternative
-    (my $config_key = $this_package) =~ s/^Catalyst:://;
-    if (exists $class->config->{$config_key}
-        and exists $class->config->{$config_key}->{basepath}) {
+    if (exists $class->config->{$this_package}
+        and exists $class->config->{$this_package}->{basepath}) {
         $class->config->{'Controller::AutoCRUD::Root'}->{action}->{base}->{PathPart}
-            = $class->config->{$config_key}->{basepath};
+            = $class->config->{$this_package}->{basepath};
     }
 
     foreach my $orig (@packages) {
@@ -97,51 +93,6 @@ sub setup_components {
     return 1;
 }
 
-# we subvert the pretty print error screen for dumpmeta
-sub dump_these {
-    my $c = shift;
-    my $params = {
-            map {$_ => $c->stash->{$_}}
-                grep {ref $c->stash->{$_} eq ''}
-                grep {$_ =~ m/^cpac_/}
-                     keys %{$c->stash},
-    };
-    if ($c->stash->{dumpmeta}) {
-        return (
-            [ 'CPAC Parameters' => $params ],
-            [ 'Site Configuration' => $c->stash->{site_conf} ],
-            [ 'Storage Metadata'   => $c->stash->{cpac_meta} ],
-            [ 'Response' => $c->response ], # only to pacify log_request
-        );
-    }
-    else { $c->next::method(@_) }
-}
-
-# monkey patch Catalyst::View::JSON until it is fixed, or users will get scared
-# by the warning currently emitted by Catalyst
-
-use Catalyst::View::JSON;
-my $json_new = _get_subref('new', 'Catalyst::View::JSON');
-{
-    no warnings 'redefine';
-    *Catalyst::View::JSON::new = sub {
-        delete $_[2]->{catalyst_component_name};
-        goto $json_new;
-    };
-}
-
-sub _get_subref {
-    my $sub = shift;
-    my $pkg = shift || scalar caller(0);
-
-    my $symtbl = \%{main::};
-    foreach my $part(split /::/, $pkg) {
-        $symtbl = $symtbl->{"${part}::"};
-    }
-
-    return eval{ \&{ $symtbl->{$sub} } };
-}
-
 1;
 
 __END__
@@ -152,7 +103,14 @@ Catalyst::Plugin::AutoCRUD - Instant AJAX web front-end for DBIx::Class
 
 =head1 VERSION
 
-This document refers to version 0.68 of Catalyst::Plugin::AutoCRUD
+This document refers to version 0.42 of Catalyst::Plugin::AutoCRUD
+
+=head1 WARNING
+
+This is an I<ALPHA RELEASE>. I'd really appreciate any bug reports; you can
+use the CPAN RT bug tracking system, or email me (Oliver) directly at the
+address at the bottom of this page. Please also be aware that the
+configuration file content has changed from previous releases of the module.
 
 =head1 PURPOSE
 
@@ -165,7 +123,7 @@ to create such interfaces on the fly. They are a bit whizzy and all Web
 
 If you already have a L<Catalyst> app with L<DBIx::Class> models configured:
 
- use Catalyst qw(AutoCRUD); # <-- add the plugin name here in MyApp.pm
+ use Catalyst qw(AutoCRUD); # <-- add the plugin name here in myapp.pm
 
 Now load your app in a web browser, but add C</autocrud> to the URL path.
 
@@ -193,7 +151,7 @@ Retrieve, Update, Delete and Search operations.
 
 The interface is not written to static files on your system, and uses AJAX to
 act upon the database without reloading your web page (much like other
-Web 2.0 applications, for example Google Mail).
+Web 2.0 appliactions, for example Google Mail).
 
 Almost all the information required by the plugin is retrieved from the
 L<DBIx::Class> ORM frontend to your database, which it is expected that you
@@ -205,19 +163,22 @@ interface after a page refresh.
 
 =head2 Read Me First
 
-If you created your C<DBIx::Class> Schema some time ago, perhaps using an
-older version of C<DBIx::Class::Schema::Loader>, then it might well be lacking
-some configuration which is required to get the best results from this plugin.
+If you're upgrading from L<CatalystX::ListFramework::Builder>, please note the
+following important changes:
 
-Common omissions in column configurations include C<is_foreign_key>,
-C<join_type>, C<is_nullable>, and C<is_auto_increment>. Of course it's also
-good practice to have your C<DBIx::Class> Schema closely reflect the database
-schema anyway.
+=over 4
 
-To automatically bring things up to date, download the latest version of
-L<DBIx::Class::Schema::Loader> from CPAN (which may be 0.05 or a pre-release),
-and use the output from that. If you don't yet have a Schema, continue reading
-and Scenario 2, below, will cover the steps required.
+=item *
+
+The base URL path now defaults to C</autocrud> if you don't set it.  Override
+this with the C<basepath> option.
+
+=item * 
+
+You probably want to delete the C<extjs2> option from your config, as this
+plugin can now pull the files from CacheFly.
+
+=back
 
 =head2 Scenario 1: Plugin to an existing Catalyst App
 
@@ -240,7 +201,7 @@ be offered a Home screen to select the database, and then another menu to
 select the table within that.
 
 Remember that the pages available from this plugin will be located under the
-C</autocrud> path of your application. Use the C<basepath> option if you want
+C</autocrud> path if your application. Use the C<basepath> option if you want
 to override this.
 
 =head2 Scenario 2: Frontend for an existing C<DBIx::Class::Schema> based class
@@ -323,8 +284,7 @@ existing one from disk).
 
 When AutoCRUD loads it will connect to the database and use the
 L<DBIx::Class::Schema::Loader> module to reverse engineer its schema. To work
-properly you'll need the very latest version of that module (at least 0.05,
-or the most recent development release from CPAN).
+properly you'll need the very latest version of that module (0.05 or greater).
 
 The other drawback to this scenario (other than the slower operation) is that
 you have no ability to customize how foreign, related records are shown.  A
@@ -334,23 +294,6 @@ of the foreign table, the names of the primary keys, and associated values
 
 =head1 TIPS AND TRICKS
 
-=head2 Update your C<DBIx::Class> Result Classes
-
-If you created your C<DBIx::Class> Schema some time ago, perhaps using an
-older version of C<DBIx::Class::Schema::Loader>, then it might well be lacking
-some configuration which is required to get the best results from this plugin.
-
-Common omissions in column configurations include C<is_foreign_key>,
-C<join_type>, C<is_nullable>, and C<is_auto_increment>. Of course it's also
-good practice to have your C<DBIx::Class> Schema closely reflect the database
-schema anyway.
-
-To automatically bring things up to date, download the latest version of
-L<DBIx::Class::Schema::Loader> from CPAN (which may be 0.05 or a pre-release),
-and use the output from that.
-
-More detail is given in the L</TROUBLESHOOTING> section, below.
-
 =head2 Representing related records
 
 When the web interface wants to display a column which references another
@@ -381,28 +324,12 @@ foreign row. This is something approximating the name of the foreign table,
 the names of the primary keys, and associated values. It's better than
 stringifying the object the way Perl does, anyway.
 
-=head2 Textfields and Textareas
+=head2 Columns with auto-increment data types
 
-When the plugin creates a web form for adding or editing, it has to choose
-whether to show a Textfield or Textarea for text-type fields. If you have set
-a C<size> option in add_columns() within the Schema, and this is less than or
-equal to 40, a Textfield is used. Otherwise, if the C<size> option is larger
-than 40 or not set, then an auto-expanding, scrollable Textarea is used.
-
-=head2 Column names with spaces
-
-The plugin will handle most tricky names, but you should remember to pass some
-required extra quoting hints to DBIx::Class when it makes a connection to your
-database:
-
- # most databases:
- { quote_char => q{`}, name_sep => q{.} }
-  
- # SQL Server:
- { quote_char => [qw/[ ]/], name_sep => q{.} }
-
-For more information see the L<DBIx::Class::Storage::DBI> manual page or ask
-on the DBIx::Class mail list.
+For those columns where your database uses an auto-incremented value, add the
+C<< is_auto_increment => 1, >> option to the relevant hash in add_columns().
+This will let the plugin know you don't need to supply a value for new or
+updated records. The interface will look much better as a result.
 
 =head2 Database IO filters
 
@@ -420,22 +347,21 @@ path on your web site. To that end, the plugin by default places its pages
 under a path part of C<...E<sol>autocrudE<sol>>. You can change this by adding
 the following option to your configuration file:
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     basepath admin
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 In the above example, the path C<...E<sol>adminE<sol>> will contain the AutoCRUD
 application, and all generated links in AutoCRUD will also make use of that path.
 Remember this is added to the C<base> of your Cataylst application which,
 depending on your web server configuration, might also have a leading path.
 
-To have the links based at the root of your application (which was the default
-behaviour of C<CatalystX::ListFramework::Builder>, set this variable to an
-empty string in your configuration:
+To have the links based at the root of your application, set this variable to
+an empty string in your configuration:
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     basepath ""
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 =head2 Using your own ExtJS libraries
 
@@ -452,54 +378,15 @@ Install it to your web server in a location that it is able to serve as static
 content. Make a note of the path used in a URL to retrieve this content, as it
 will be needed in the application configuration file, like so:
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     extjs2  /static/javascript/extjs-2
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 Use the C<extjs2> option as shown above to specify the URL path to the
 libraries. This will be used in the templates in some way like this:
 
  <script type="text/javascript" src="[% c.config.extjs2 %]/ext-all.js" />
 
-=head2 Changing the HTML Character Set
-
-The default HTML C<charset> used by this module is C<utf-8>. If you wish to override
-this, then set the C<html_charset> parameter, as below:
-
- <Plugin::AutoCRUD>
-    html_charset  iso-8859-1
- </Plugin::AutoCRUD>
-
-=head2 Simple read-only non-JavaScript Frontend
-
-All table views will default to the full-featured ExtJS based frontend. If you
-would prefer to see a simple read-only non-JavaScript interface, then append
-C</browse> to your URL.
-
-This simpler frontend uses HTTP GET only, supports paging and sorting, and
-will obey any column filtering and renaming as set in your L</"SITES CONFIGURATION"> file.
-
-=head2 Overriding built-in Templates
-
-The whole site is built from Perl Template Toolkit templates, and it is
-possible to override these shipped templates with your own files. This goes
-for both general files (CSS, top-level TT wrapper) as well as the site files
-mentioned in the next section.
-
-To add these override paths, include the following directive in your
-configuration file:
-
- <Plugin::AutoCRUD>
-    tt_path /path/to/my/local/templates
- </Plugin::AutoCRUD>
-
-This C<tt_path> directive can be included multiple times to set a list of
-override paths, which will be processed in the order given.
-
-If you want to override any of the CSS used in the app, copy the C<wrapper.tt>
-template from whichever C<site> you are using, edit, and install in a local
-C<tt_path> set with this directive.
-
 =head1 SITES CONFIGURATION
 
 Another feature borrowed from the original L<CatalystX::ListFramework> is the
@@ -514,13 +401,13 @@ default site, which unsurprisingly is called C<default>. To override settings
 in this, create the following configuration stub, and fill it in with any of
 the options listed below:
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     <sites>
         <default>
             # override settings here
         </default>
     </sites>
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 =head2 Configuration Options for Sites
 
@@ -539,7 +426,7 @@ Some of the options are I<global> for a site, others apply to the schema or
 sources within it. To specify an option for one or the other, use the schema
 and source names I<as they appear in the URL path>:
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     <sites>
         <default>
             # global settings for the site, here
@@ -551,7 +438,7 @@ and source names I<as they appear in the URL path>:
             </myschema>
         </default>
     </sites>
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 =head3 Options
 
@@ -559,129 +446,82 @@ and source names I<as they appear in the URL path>:
 
 =item update_allowed [ yes* | no ]
 
-This can be applied to either a schema or a source; if applied to a schema it
+This can be applied to either a schema or source; if applied to a schema it
 percolates to all the sources, unless the source has a different setting.
 
-The default is to allow updates to be made to existing records. Set this to a
-value of C<no> to prevent this operation from being permitted.  Widgets will
-also be removed from the user interface so as not to confuse users.
+The default is to allow updates to be made to records in the sources. Set this
+to a value of C<no> to prevent updates from being allowed. Widgets will also
+be removed from the user interface so as not to confuse users.
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     <sites>
         <default>
-            update_allowed no
+            update_alowed no
         </default>
     </sites>
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
-Although this is a separate option from C<create_allowed>, below, I<be warned!>
-Both creation and editing of records are in fact C<update> actions, so the
-I<only> way to secure the application from creation and editing of records is
-to set this option to C<no>.
-
-=item create_allowed [ yes* | no ]
-
-This can be applied to either a schema or a source; if applied to a schema it
-percolates to all the sources, unless the source has a different setting.
-
-The default is to allow new records to be created. Set this to a value of
-C<no> to prevent this operation from being allowed.  Widgets will also be
-removed from the user interface so as not to confuse users.
-
- <Plugin::AutoCRUD>
-    <sites>
-        <default>
-            create_allowed no
-        </default>
-    </sites>
- </Plugin::AutoCRUD>
-
-I<Important Note:> this is purely a cosmetic action, and it is still possible
-for a user to call the AJAX API published by this application in order to
-create a new record. The only way truely to prevent record creation is also
-to set the C<update_allowed> option to C<no>, as shown above.
+B<Important note:> this setting applies to both the creation of new records in
+your source, as well as the updating of existing records.
 
 =item delete_allowed [ yes* | no ]
 
-This can be applied to either a schema or a source; if applied to a schema it
+This can be applied to either a schema or source; if applied to a schema it
 percolates to all the sources, unless the source has a different setting.
 
 The default is to allow deletions of records in the sources. Set this to a
 value of C<no> to prevent deletions from being allowed. Widgets will also be
 removed from the user interface so as not to confuse users.
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     <sites>
         <default>
             delete_allowed no
         </default>
     </sites>
- </Plugin::AutoCRUD>
-
-=item columns \@column_names
-
-This option achieves two purposes. First, you can re-order the set of columns
-as they are displayed to the user. Second, by omitting columns from this list
-you can hide them from the main table views.
-
-Provide a list of the column names (as the data source knows them) to this
-setting. This option must appear at the source level of your site config
-hierarchy. In C<Config::General> format, this would look something like:
-
- <Plugin::AutoCRUD>
-    <sites>
-        <default>
-            <myschema>
-                <thesource>
-                    columns  id
-                    columns  title
-                    columns  length
-                </thesource>
-            </myschema>
-        </default>
-    </sites>
- </Plugin::AutoCRUD>
-
-Any columns existing in the source, but not mentioned there, will not be
-displayed in the main table. They'll still appear in the record edit form, as
-some fields are required by the database schema so cannot be hidden. Columns
-will be displayed in the same order that you list them in the configuration.
-
-=item headings { col => title, ... }
-
-You can alter the title given to any column in the user interface, by
-providing a hash mapping of column names (as the data source knows them) to
-titles you wish displayed to the user. This option must appear at the source
-level of your site config hierarchy. In C<Config::General> format, this would
-look something like:
-
- <Plugin::AutoCRUD>
-    <sites>
-        <default>
-            <myschema>
-                <thesource>
-                    <headings>
-                        id      Key
-                        title   Name
-                        length  Time
-                    </headings>
-                </thesource>
-            </myschema>
-        </default>
-    </sites>
- </Plugin::AutoCRUD>
-
-Any columns not included in the hash mapping will use the default title (i.e.
-what the plugin works out for itself). To hide a column from view, use the
-C<columns> option, described above.
+ </Catalyst::Plugin::AutoCRUD>
 
 =item list_returns [ \@columns | { col => title, ... } ]
 
-This configuration option is I<DEPRECATED>. Please see C<columns> to control
-which columns are displayed to users and, independently, C<headings> to alter
-the titles displayed for any columns. The plugin still respects a
-C<list_returns> configuration setting but will emit a warning to your log that
-you need to migrate to the new, more flexible, alternatives.
+To restrict the set of columns displayed, provide a list of the column names
+(as the data source knows them) to this setting. In C<Config::General> format,
+this would look something like:
+
+ <Catalyst::Plugin::AutoCRUD>
+    <sites>
+        <default>
+            list_returns    id
+            list_returns    title
+            list_returns    length
+        </default>
+    </sites>
+ </Catalyst::Plugin::AutoCRUD>
+
+So any columns existing in the source, but not mentioned there, will not be
+displayed in the main table. They'll still appear in the record edit form, but
+that might be fixed in a future version of this plugin. If using this
+feauture, you probably want to also use C<update_allowed no> to preserve your
+users' sanity.
+
+At the same time, you can alter the titles given to some columns in the user
+interface, by changing this option from a list to a hash form:
+
+ <Catalyst::Plugin::AutoCRUD>
+    <sites>
+        <default>
+            <list_returns>
+                id      Key
+                title   Name
+                length  Time
+            </list_returns>
+        </default>
+    </sites>
+ </Catalyst::Plugin::AutoCRUD>
+
+Here, the columns are still restricted, and their titles are changed to the
+values on the right hand side. To use the default value for a column (i.e.
+what the Plugin works out for itself), just omit the value on the right hand
+side.
 
 =item hidden [ yes | no* ]
 
@@ -689,7 +529,7 @@ If you don't want a schema to be offered to the user, or likewise a particular
 source, then set this option to C<yes>. By default, all schema and sources are
 shown in the user interface.
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     <sites>
         <default>
             <myschema>
@@ -699,35 +539,21 @@ shown in the user interface.
             </myschema>
         </default>
     </sites>
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 This can be applied to either a schema or source; if applied to a schema it
 overrides all child sources, B<even if> a source has a different setting.
 
 =item frontend [ full-fat | skinny | ... ]
 
-With this option you can swap out the set of templates used to generate the
-web front-end, and completely change its look and feel.
+This option isn't fully implemented. It allows you to swap out the set of
+templates used to generate the web front-end. At the moment, only the
+C<full-fat> option is implemented, and it's the ExtJS front-end you'll be
+familiar with.
 
-Currently you have two choices: either C<full-fat> which is the default and
-provides the standard full-featured ExtJS frontend, or C<skinny> which is a
-read-only non-JavaScript alternative supporting listing, paging and sorting
-only.
-
-Set the frontend in your site config at its top level. Note that you cannot
-set the frontend on a per-schema or per-source basis, only per-site:
-
- <Plugin::AutoCRUD>
-    <sites>
-        <default>
-            frontend skinny
-        </default>
-    </sites>
- </Plugin::AutoCRUD>
-
-Be aware that setting the frontend to C<skinny> does B<not> restrict create or
-update access to your database via the AJAX API. For that, you still should
-set the C<*_allowed> options listed above, as required.
+The C<skinny> front-end is just a stub (you can try if it you like), and I'm
+hoping someone will write HTML/CSS with a more lightweight JS library such as
+JQuery or YUI, and submit that.
 
 =back
 
@@ -736,13 +562,13 @@ set the C<*_allowed> options listed above, as required.
 You can create a new site by adding it to the C<sites> section of your
 configuration:
 
- <Plugin::AutoCRUD>
+ <Catalyst::Plugin::AutoCRUD>
     <sites>
         <mysite>
             # local settings here
         </mysite>
     </sites>
- </Plugin::AutoCRUD>
+ </Catalyst::Plugin::AutoCRUD>
 
 You'll notice that a non-default site is active because the path in your URLs
 changes to a more RPC-like verbose form, mentioning the site, schema and
@@ -764,78 +590,6 @@ to users:
 You could also then place an access control on this path part in your web
 server (e.g. Apache) which is different from the default site itself.
 
-=head1 TROUBLESHOOTING
-
-=head2 Foreign keys should be configured with C<is_foreign_key>
-
-Any column in your result classes which contains the primary key of another
-table should have the C<< is_foreign_key => 1 >> option added to its
-configuration.
-
-Not doing this will cause the affected column to appear twice in your table,
-with a C<(REF)> suffix on the heading, rather than once with an C<(FK)>
-suffix.  The technical reason for this, if you are interested, is that
-C<is_foreign_key> is used by this plugin to differentiate between C<has_one>
-and C<belongs_to> type relations. The plugin will emit an error level log
-message if it detects this problem.
-
-If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
-version 0.05 or the most recent development release from CPAN to have this
-automatically configured for you.
-
-=head2 Make sure C<belongs_to> follows C<add_columns>
-
-Whenver you use C<belongs_to()> in a result class, it B<must> come after any
-calls to C<add_column()> which affect the foreign key. A situation where this
-may not be the case is if you add additional column options in a second call
-to C<add_column()>, after the C<DO NOT MODIFY THIS OR ANYTHING ABOVE> line.
-
-If you do not follow this guideline, then you won't see any related data in 
-the views generated by this plugin. Furthermore, you'll be losing much of
-the advantage of C<DBIx::Class>, so this plugin will emit an error log
-level message if it detects this problem.
-
-A better solution is to re-generate your result class using a recent version
-of C<DBIx::Class::Schema::Loader> from the CPAN (which may be 0.05 or a
-pre-release).
-
-=head2 Optional C<belongs_to> relations must have a C<join_type>
-
-If you have any C<belongs_to> type relations where the column containing the
-foreign key can be NULL, it's I<strongly recommended> that you add a
-C<join_type> parameter to the end of the relevant options to C<add_columns()>,
-like so:
-
- # in a Book class, the book optionally has an Owner
- __PACKAGE__->belongs_to(
-     'my_owner',                      # accessor name
-     'My::DBIC::Schema::Owner',       # related class
-     'owner_id',                      # our FK column (or join condition)
-     { join_type => 'LEFT OUTER' }    # attributes
- );
-
-If you don't do this, some database records will be missing! The plugin will
-emit an error level log message if it detects this problem. The technical
-reason for this, if you are interested, is that C<DBIx::Class> defaults to an
-INNER join for the C<belongs_to()> relation, but if the column can be null (that
-is, C<is_nullable>) then you most likely want a LEFT OUTER join.
-
-If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
-version 0.05 or the most recent development release from CPAN to have this
-automatically configured for you.
-
-=head2 Columns with auto-increment data types
-
-For those columns where your database uses an auto-incremented value, add the
-C<< is_auto_increment => 1 >> parameter to the options list in
-C<add_columns()>.  This will let the plugin know you don't need to supply a
-value for new or updated records. The interface will look much better as a
-result.
-
-If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
-version 0.05 or the most recent development release from CPAN to have this
-automatically configured for you.
-
 =head1 EXAMPLES
 
 The code examples given above in this manual are also supplied in the form of
@@ -854,7 +608,7 @@ to work, you must have:
 =item *
 
 The very latest version of L<DBIx::Class::Schema::Loader> installed on your
-system (at least 0.05, or the most recent developemnt release from CPAN).
+system (> 0.04005).
 
 =item *
 
@@ -879,7 +633,7 @@ voila!
 To use your own database rather than the SQLite demo, edit
 C<examples/demo/demo.conf> so that it contains the correct C<dsn>, username,
 and password for your database. Upon restarting the application you should see
-your own data source instead.
+your own data source instaed.
 
 =head1 LIMITATIONS
 
@@ -897,13 +651,6 @@ If you have two columns which both have foreign key constraints to the same
 table, it's very likely AutoCRUD will not work. Again this is a simplification
 which speeded the initial development.
 
-=item Time Zone settings are lost during SELECT/UPDATE
-
-Database fields of types such as (PostgreSQL) C<timestamp with time zone> will
-be displayed with a date and time picker, but you'll lose the time zone's UTC
-offset value, sorry. This could be fixed and retained through an improved UI
-widget, for example.
-
 =back
 
 For the issues above, if you're desperate that the feature be implemented
@@ -970,7 +717,7 @@ This distribution ships with the Ext.ux.form.DateTime Extension Class for Ext
 2.x Library, Copyright (c) 2008, Ing. Jozef Sakalos, and released under the
 LGPL 3.0 license (library version 289, 2008-06-12 21:08:08).
 
-The rest is Copyright (c) Oliver Gorwits 2009.
+The rest is Copyright (c) Oliver Gorwits 200999999999.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
