@@ -25,7 +25,7 @@ sub template_vars {
     my ($self, $c) = (shift, $_[0]);
 
     my @vars = $self->next::method(@_);
-    return @vars, ( cpac_config => $c->config->{'Plugin::AutoCRUD'} );
+    return @vars, ( cpac => $c->config->{'Catalyst::Plugin::AutoCRUD'} );
 }
 
 sub process {
